#! /bin/sh

#Bootsplash Theme Creator
#Version 1.6

#This program allows you to use a .jpg picture that you provide as a bootsplash theme.

#Created by Daniel for VectorLinux

#Released under the GPL license v2.1.


#Checking to make sure that the user is root.
user=$(whoami)
if [ "$user" != "root" ];then
  zenity --info --title="Bootsplash Theme Creator" --text="This program must be run by root. You are $user."
  exit 0
fi

#Introducing user to program.
zenity --info --title="Bootsplash Theme Creator" --text="This program allows you to use a .jpg picture that you provide as a bootsplash theme."

#Question about name of picture.
zenity --question --title="Picture" --text="The name of the picture that you intend to use cannot contain any spaces.

Continue?"
if [ "$?" = 1 ];then
  exit 0
fi

#Getting the name of the new theme.
name=$(zenity --entry --title="Name of new theme." --text="Please enter a name for your new theme:")
if [ "$?" = 1 ];then
  exit 0
fi

#Checking to make sure that the new theme name doesn't already exist.
check=$(ls /etc/bootsplash/themes/$name/)
if $check ;then
  echo "doesn't exist"
else
  zenity --question --title="File Exists" --text="The $name theme already exists. Do you want to overwrite it?"
  if [ "$?" = 1 ];then
    exit 0
  fi
 cd /etc/bootsplash/themes/
 rmdir $name/
fi

#Getting the location of .jpg file.
zenity --info --title="Picture" --text="Please select the .jpg picture that you want to use."
pic=$(zenity --file-selection --title="Location of .jpg file.")
if [ "$?" = 1 ];then
  exit 0
fi

#Checking whether selected pic is a .jpg or not.
type=$(find $pic -name '*.jpg')
if [ $type ];then
 echo "yes"
else
zenity --info --title="Picture" --text="The picture you selected is not a .jpg picture. Please select a .jpg picture."
pic=$(zenity --file-selection --title="Location of .jpg file.")
if [ "$?" = 1 ];then
  exit 0
fi

fi

#Question about filesize.
size=$(identify -verbose $pic | grep Filesize)
zenity --question --title="File size" --text="The filesize of your picture should be less than about 500kb. The bigger the filesize, the slower your computer will boot up while using the bootsplash. Very large pictures may not work at all.

For your selected picture, $size

Do you want to continue?"
if [ "$?" = 1 ];then
  exit 0
fi

#Confirmation
zenity --question --title="Confirmation" --text="Please confirm that these settings are correct.

Name of new theme: $name

location of .jpg file: $pic

Is this correct?"
if [ "$?" = 1 ];then
  exit 0
fi

#Making directories, copying configuration files.

zenity --progress --pulsate --title="working..." --text="Making directories, copying files..." --percentage=20 --timeout 1

cd /etc/bootsplash/themes/
mkdir $name/
cd $name/
mkdir config/
mkdir images/
cd /etc/bootsplash/themes/current/config/
cp bootsplash-1024x768.cfg /etc/bootsplash/themes/$name/config/
cp bootsplash-1280x1024.cfg /etc/bootsplash/themes/$name/config/
cp bootsplash-800x600.cfg /etc/bootsplash/themes/$name/config/

#Copying and resizing the .jpg file.

zenity --progress --pulsate --title="working..." --text="Copying and resizing .jpg..." --percentage=40 --timeout 1

convert $pic -resample 72 -sampling-factor 2x2 -resize 1024x768\! /etc/bootsplash/themes/$name/images/bootsplash-1024x768.jpg

convert $pic -resample 72 -sampling-factor 2x2 -resize 1280x1024\! /etc/bootsplash/themes/$name/images/bootsplash-1280x1024.jpg

convert $pic -resample 72 -sampling-factor 2x2 -resize 800x600\! /etc/bootsplash/themes/$name/images/bootsplash-800x600.jpg

#Copying and resizing the silent .jpg files.

zenity --progress --pulsate --title="working..." --text="Copying and resizing silent .jpg..." --percentage=60 --timeout 1

convert $pic -resample 72 -sampling-factor 2x2 -resize 1024x768\! /etc/bootsplash/themes/$name/images/silent-1024x768.jpg

convert $pic -resample 72 -sampling-factor 2x2 -resize 1280x1024\! /etc/bootsplash/themes/$name/images/silent-1280x1024.jpg

convert $pic -resample 72 -sampling-factor 2x2 -resize 800x600\! /etc/bootsplash/themes/$name/images/silent-800x600.jpg

#Changing the configuration files to point to the correct jpeg - for 1024x768

zenity --progress --pulsate --title="working..." --text="Changing configuration files..." --percentage=80 --timeout 1

sed -i 's|'$(grep -i '^jpeg=' /etc/bootsplash/themes/current/config/bootsplash-1024x768.cfg)'|jpeg=/etc/bootsplash/themes/'$name'/images/bootsplash-1024x768.jpg|g' /etc/bootsplash/themes/$name/config/bootsplash-1024x768.cfg

sed -i 's|'$(grep -i '^silentjpeg=' /etc/bootsplash/themes/current/config/bootsplash-1024x768.cfg)'|silentjpeg=/etc/bootsplash/themes/'$name'/images/silent-1024x768.jpg|g' /etc/bootsplash/themes/$name/config/bootsplash-1024x768.cfg

# - for 1280x1024
sed -i 's|'$(grep -i '^jpeg=' /etc/bootsplash/themes/current/config/bootsplash-1280x1024.cfg)'|jpeg=/etc/bootsplash/themes/'$name'/images/bootsplash-1280x1024.jpg|g' /etc/bootsplash/themes/$name/config/bootsplash-1280x1024.cfg

sed -i 's|'$(grep -i '^silentjpeg=' /etc/bootsplash/themes/current/config/bootsplash-1280x1024.cfg)'|silentjpeg=/etc/bootsplash/themes/'$name'/images/silent-1280x1024.jpg|g' /etc/bootsplash/themes/$name/config/bootsplash-1280x1024.cfg

# - and for 800x600
sed -i 's|'$(grep -i '^jpeg=' /etc/bootsplash/themes/current/config/bootsplash-800x600.cfg)'|jpeg=/etc/bootsplash/themes/'$name'/images/bootsplash-800x600.jpg|g' /etc/bootsplash/themes/$name/config/bootsplash-800x600.cfg

sed -i 's|'$(grep -i '^silentjpeg=' /etc/bootsplash/themes/current/config/bootsplash-800x600.cfg)'|silentjpeg=/etc/bootsplash/themes/'$name'/images/silent-800x600.jpg|g' /etc/bootsplash/themes/$name/config/bootsplash-800x600.cfg

zenity --progress --pulsate --title="Finished" --text="Your new theme has been created." --percentage=100 --timeout 3
zenity --question --title="Next?" --text="Do you want to run the VL Bootsplash Switcher to switch to your new theme?"
if [ "$?" = 1 ];then
  exit 0
fi
/sbin/VLbsplash-switch